Skip to contents

Align two surface cross cuts according to maximal correlation

Usage

sig_align(
  sig1,
  sig2,
  min.overlap = round(0.75 * min(length(sig1), length(sig2)))
)

Arguments

sig1

vector of first signature

sig2

vector of second signature

min.overlap

additional parameter passed on to get_ccf

Value

list consisting of a) the maximal cross correlation, b) the lag resulting in the highest cross correlation, and c) same data frame as input, but y vectors are aligned for maximal correlation d) list of a vector of correlations and a vector of lags