Skip to contents

A readable link to the doi for a data repo would be much better, here.

Usage

toolmarks

Format

toolmarks

A data frame with 38,6712 rows and 13 columns:

x

numeric value of the x location in ???

y

numeric value of the y location in ???

value

numeric value of the surface height in ???

signature

numeric value the signal height

tool

tool ID, value between 1 and 20

mark

iteration, value between 1 and 8

side

screwdriver side that made the mark, A or B.

angle

angle of attack, one of 60, 70, or 80.

material

for now all marks are made on lead plates 'Pb'.

direction

direction of the toolmark 'Fo'rward/Pull or 'Ba'ckward/Push.

size

size of the screwdriver, 'S', 'M', or 'L'

Maria Cuellar, CSAFE collaborative agreement with NIST.