Align two surface cross cuts according to maximal correlation
Arguments
- sig1
vector of first signature
- sig2
vector of second signature
- min.overlap
additional parameter passed on to get_ccf
Value
list consisting of
a) the maximal cross correlation,
b) the lag resulting in the highest cross correlation, and
c) same data frame as input, but y vectors are aligned for
maximal correlation
d) list of a vector of correlations and a vector of lags